Handler

Struct Handler 

pub struct Handler<T> { /* private fields */ }
Handler

Handler is a struct that wraps a raw pointer and a drop flag.

Memory is freed automatically when Handler goes out of scope (via Drop). You must ensure the Handler outlives the Aeron session that uses it, since Aeron holds a raw clientd pointer to the boxed value and will call callbacks until closed.

Call release() early if you want to free the memory before the Handler drops.

Example

use rusteron_code_gen::Handler;
let handler = Handler::leak(your_value);
// handler is freed automatically when it goes out of scope

Implementations

Source

impl<T> Handler<T>

pub fn leak(handler: T) -> Self

pub fn is_none(&self) -> bool

pub fn as_raw(&self) -> *mut c_void

pub fn release(&mut self)

pub unsafe fn new(raw_ptr: *mut T, should_drop: bool) -> Self