pub struct Handler<T> { /* private fields */ }Expand description
Handler
Handler is a struct that wraps a raw pointer and a drop flag.
Memory is freed automatically when Handler goes out of scope (via Drop).
You must ensure the Handler outlives the Aeron session that uses it, since Aeron
holds a raw clientd pointer to the boxed value and will call callbacks until closed.
Call release() early if you want to free the memory before the Handler drops.
Example
use rusteron_code_gen::Handler;
let handler = Handler::leak(your_value);
// handler is freed automatically when it goes out of scopeImplementations